=========
napari-dv
=========

.. image:: https://img.shields.io/pypi/v/napari-dv.svg
    :target: https://pypi.org/project/napari-dv
    :alt: PyPI version

.. image:: https://img.shields.io/pypi/pyversions/napari-dv.svg
    :target: https://pypi.org/project/napari-dv
    :alt: Python versions

.. image:: https://travis-ci.org/tlambert03/napari-dv.svg?branch=master
    :target: https://travis-ci.org/tlambert03/napari-dv
    :alt: See Build Status on Travis CI

.. image:: https://ci.appveyor.com/api/projects/status/github/tlambert03/napari-dv?branch=master
    :target: https://ci.appveyor.com/project/tlambert03/napari-dv/branch/master
    :alt: See Build Status on AppVeyor

Deltavision/MRC file reader plugin for napari

----

This `napari`_ plugin was generated with `Cookiecutter`_ along with
`@napari`_'s `cookiecutter-napari-plugin`_ template.


Installation
------------

You can install "napari-dv" via `pip`_ from `PyPI`_::

    $ pip install napari-dv


License
-------

Distributed under the terms of the `MIT`_ license,
"napari-dv" is free and open source software


Issues
------

If you encounter any problems, please `file an issue`_ along with a detailed description.

.. _`Cookiecutter`: https://github.com/audreyr/cookiecutter
.. _`@napari`: https://github.com/napari
.. _`MIT`: http://opensource.org/licenses/MIT
.. _`BSD-3`: http://opensource.org/licenses/BSD-3-Clause
.. _`GNU GPL v3.0`: http://www.gnu.org/licenses/gpl-3.0.txt
.. _`Apache Software License 2.0`: http://www.apache.org/licenses/LICENSE-2.0
.. _`cookiecutter-napari-plugin`: https://github.com/napari/cookiecutter-napari-plugin
.. _`file an issue`: https://github.com/tlambert03/napari-dv/issues
.. _`napari`: https://github.com/napari/napari
.. _`tox`: https://tox.readthedocs.io/en/latest/
.. _`pip`: https://pypi.org/project/pip/
.. _`PyPI`: https://pypi.org/project
